@@ -19,6 +19,15 @@ class BackendStore {
 	public const BACKEND_DIR = "/"; // path to search for core backends, relative to current path
 	public const LOG_CONTEXT = "BackendStore"; // Context for the Logger
 
+	/**
+	 * Mapping of legacy backend names to their canonical replacements.
+	 *
+	 * @var array<string, string>
+	 */
+	private $backendAliases = [
+		'Owncloud' => 'Default',
+	];
+
 	/**
 	 * Feature variables.
 	 */
@@ -36,7 +45,9 @@ class BackendStore {
 
 	// Make it a singleton
 	private function __construct() {
-		$this->EXTERNAL_BACKEND_DIR = BASE_PATH . PATH_PLUGIN_DIR . "/";
+		// Be tolerant if PATH_PLUGIN_DIR is not defined in config.php
+		$pluginsDir = defined('PATH_PLUGIN_DIR') ? constant('PATH_PLUGIN_DIR') : 'plugins';
+		$this->EXTERNAL_BACKEND_DIR = BASE_PATH . rtrim($pluginsDir, '/') . "/";
 
 		Logger::debug(self::LOG_CONTEXT, "Searching for external backends in " . $this->EXTERNAL_BACKEND_DIR);
 	}
@@ -114,6 +125,8 @@ class BackendStore {
 	/**
 	 * Registration adds the backend to the list of plugins, and also
 	 * includes it's code into our runtime.
+	 *
+	 * @param mixed $backend
 	 */
 	private function register($backend) {
 		require_once __DIR__ . self::BACKEND_DIR . $backend . "/class.backend.php";
@@ -123,6 +136,8 @@ class BackendStore {
 	/**
 	 * Registration adds the external backend to the list of plugins, and also
 	 * includes it's code into our runtime.
+	 *
+	 * @param mixed $backend
 	 */
 	private function registerExternal($backend) {
 		require_once $this->EXTERNAL_BACKEND_DIR . self::EXTERNAL_BACKEND_PREFIX . $backend . "/php/class.backend.php";
@@ -132,11 +147,14 @@ class BackendStore {
 	/**
 	 * Check if a backend is registered.
 	 *
+	 * @param mixed $backend
+	 *
 	 * @return bool
 	 */
 	public function backendExists($backend) {
+		$canonical = $this->normalizeBackendName($backend);
 		foreach ($this->backends as $registeredbackend) {
-			if ($backend === $registeredbackend) {
+			if ($canonical === $registeredbackend) {
 				return true;
 			}
 		}
@@ -149,11 +167,14 @@ class BackendStore {
 	/**
 	 * Creates a new Instance of the given backendtype.
 	 *
+	 * @param mixed $backend
+	 *
 	 * @return AbstractBackend
 	 */
 	public function getInstanceOfBackend($backend) {
-		if ($this->backendExists($backend)) {
-			$class = "\\Files\\Backend\\{$backend}\\Backend";
+		$canonical = $this->normalizeBackendName($backend);
+		if ($this->backendExists($canonical)) {
+			$class = "\\Files\\Backend\\{$canonical}\\Backend";
 
 			return new $class();
 		}
@@ -161,6 +182,17 @@ class BackendStore {
 		return false; // return false if the backend does not exist
 	}
 
+	/**
+	 * Normalize backend identifier to canonical name.
+	 *
+	 * @param string $backend
+	 *
+	 * @return string
+	 */
+	public function normalizeBackendName($backend) {
+		return $this->backendAliases[$backend] ?? $backend;
+	}
+
 	/**
 	 * Return all registered backend internal names.
 	 *
