@@ -1,8 +1,10 @@
 <?php
+
 /**
  * A custom exception class for webdav exceptions.
  *
  * @class   BackendException
+ *
  * @extends Exception
  */
 
@@ -29,8 +31,8 @@ class Exception extends \Exception {
 	 *
 	 * @return string Error code and message
 	 */
-	public function __toString() {
-		return __CLASS__ . ": [{$this->code}]: {$this->message}\n";
+	public function __toString(): string {
+		return self::class . ": [{$this->code}]: {$this->message}\n";
 	}
 
 	/**
