@@ -34,6 +34,8 @@ class AccountStore {
 	/**
 	 * @param array $backendConfig Backend specific account settings
 	 *                             like username, password, serveraddress, ...
+	 * @param mixed $name
+	 * @param mixed $backend
 	 *
 	 * @return Account
 	 */
@@ -42,6 +44,7 @@ class AccountStore {
 
 		// create instance of backend to get features
 		$backendStore = BackendStore::getInstance();
+		$backend = $backendStore->normalizeBackendName($backend);
 		$backendInstance = $backendStore->getInstanceOfBackend($backend);
 		$features = $backendInstance->getAvailableFeatures();
 
@@ -94,7 +97,9 @@ class AccountStore {
 
 		// create instance of backend to get features
 		$backendStore = BackendStore::getInstance();
-		$backendInstance = $backendStore->getInstanceOfBackend($account->getBackend());
+		$normalizedBackend = $backendStore->normalizeBackendName($account->getBackend());
+		$account->setBackend($normalizedBackend);
+		$backendInstance = $backendStore->getInstanceOfBackend($normalizedBackend);
 		$features = $backendInstance->getAvailableFeatures();
 		$account->setFeatures($features);
 
@@ -153,6 +158,8 @@ class AccountStore {
 	/**
 	 * Delete account from local store and from the MAPI settings.
 	 *
+	 * @param mixed $accountId
+	 *
 	 * @return bool
 	 */
 	public function deleteAccount($accountId) {
@@ -169,6 +176,8 @@ class AccountStore {
 	/**
 	 * Return the instance of the local account.
 	 *
+	 * @param mixed $accountId
+	 *
 	 * @return Account
 	 */
 	public function getAccount($accountId) {
@@ -188,6 +197,7 @@ class AccountStore {
 	private function initialiseAccounts() {
 		// Parse accounts from the Settings
 		$tmpAccs = $GLOBALS["settings"]->get(self::ACCOUNT_STORAGE_PATH);
+		$backendStore = BackendStore::getInstance();
 
 		if (is_array($tmpAccs)) {
 			$this->accounts = [];
@@ -231,12 +241,17 @@ class AccountStore {
 					Logger::error(self::LOG_CONTEXT, "Unsupported account version {$version}, unable to decrypt backend configuration");
 				}
 
+				$normalizedBackend = $backendStore->normalizeBackendName($acc["backend"]);
+				if ($normalizedBackend !== $acc["backend"]) {
+					$GLOBALS["settings"]->set(self::ACCOUNT_STORAGE_PATH . "/" . $acc["id"] . "/backend", $normalizedBackend);
+					$GLOBALS["settings"]->saveSettings();
+				}
 				$this->accounts[$acc["id"]] = new Account(
 					$acc["id"],
 					$acc["name"],
 					$acc["status"],
 					$acc["status_description"],
-					$acc["backend"],
+					$normalizedBackend,
 					$backend_config,
 					array_keys($acc["backend_features"]),
 					$acc["account_sequence"],
@@ -330,19 +345,28 @@ class AccountStore {
 	/**
 	 * Encrypt the given string.
 	 *
-	 * @param $version the storage version used to identify what encryption to use
+	 * @param       $version the storage version used to identify what encryption to use
+	 * @param mixed $value
 	 *
 	 * @return string
 	 */
 	private function encryptBackendConfigProperty($value, $version = 0) {
 		if ($version == self::ACCOUNT_VERSION && !is_bool($value)) {
+			// Guard against missing libsodium extension on PHP 8.1/8.2
+			if (!defined('SODIUM_CRYPTO_SECRETBOX_NONCEBYTES') || !function_exists('sodium_crypto_secretbox')) {
+				// Keep original value to avoid fatals; features may be limited
+				error_log('[Files][AccountStore] Libsodium not available for encryption; storing value as-is.');
+
+				return $value;
+			}
+
 			$nonce = random_bytes(SODIUM_CRYPTO_SECRETBOX_NONCEBYTES);
 			$key = $GLOBALS["operations"]->getFilesEncryptionKey();
 			$encrypted = sodium_crypto_secretbox((string) $value, $nonce, (string) $key);
 			$value = bin2hex($nonce) . bin2hex($encrypted);
 		}
 		elseif ($version !== self::ACCOUNT_VERSION) {
-			throw Exception("Unable to encrypt backend configuration unsupported version {$version}");
+			throw new Exception("Unable to encrypt backend configuration unsupported version {$version}");
 		}
 
 		return $value;
@@ -351,7 +375,8 @@ class AccountStore {
 	/**
 	 * Decrypt the given string.
 	 *
-	 * @param $version the storage version used to identify what encryption to use
+	 * @param       $version the storage version used to identify what encryption to use
+	 * @param mixed $value
 	 *
 	 * @return string
 	 */
@@ -361,6 +386,14 @@ class AccountStore {
 		}
 
 		if ($version == self::ACCOUNT_VERSION) {
+			// Guard against missing libsodium extension to avoid fatal errors
+			if (!defined('SODIUM_CRYPTO_SECRETBOX_NONCEBYTES') || !function_exists('sodium_crypto_secretbox_open')) {
+				// Return input as-is to avoid breaking the request path.
+				error_log('[Files][AccountStore] Libsodium not available for decryption; returning raw value.');
+
+				return $value;
+			}
+
 			$value = hex2bin((string) $value);
 			$nonce = substr($value, 0, SODIUM_CRYPTO_SECRETBOX_NONCEBYTES);
 			$encrypted = substr($value, SODIUM_CRYPTO_SECRETBOX_NONCEBYTES, strlen($value));
