@@ -1050,12 +1050,10 @@ class FilesBrowserModule extends FilesListModule {
 		if ($message && $store) {
 			// get message properties.
 			$messageProps = mapi_getprops($message, [PR_SUBJECT, PR_MESSAGE_CLASS]);
-
-			$isSupportedMessage = (
-				(stripos((string) $messageProps[PR_MESSAGE_CLASS], 'IPM.Note') === 0) ||
-				(stripos((string) $messageProps[PR_MESSAGE_CLASS], 'Report.IPM.Note') === 0) ||
-				(stripos((string) $messageProps[PR_MESSAGE_CLASS], 'IPM.Schedule') === 0)
-			);
+			$cls = $messageProps[PR_MESSAGE_CLASS];
+			$isSupportedMessage = class_match_prefix($cls, "IPM.Note") ||
+			                      class_match_prefix($cls, "Report.IPM.Note") ||
+			                      class_match_prefix($cls, "IPM.Schedule");
 
 			if ($isSupportedMessage) {
 				// Get addressbook for current session
@@ -1095,6 +1093,9 @@ class FilesBrowserModule extends FilesListModule {
 	/**
 	 * Get sharing information from the backend.
 	 *
+	 * @param mixed $actionType
+	 * @param mixed $actionData
+	 *
 	 * @return bool
 	 */
 	private function getSharingInformation($actionType, $actionData) {
@@ -1152,6 +1153,9 @@ class FilesBrowserModule extends FilesListModule {
 	/**
 	 * Create a new share.
 	 *
+	 * @param mixed $actionType
+	 * @param mixed $actionData
+	 *
 	 * @return bool
 	 */
 	private function createNewShare($actionType, $actionData) {
@@ -1211,6 +1215,9 @@ class FilesBrowserModule extends FilesListModule {
 	/**
 	 * Update a existing share.
 	 *
+	 * @param mixed $actionType
+	 * @param mixed $actionData
+	 *
 	 * @return bool
 	 */
 	private function updateExistingShare($actionType, $actionData) {
@@ -1264,6 +1271,9 @@ class FilesBrowserModule extends FilesListModule {
 	/**
 	 * Delete one or more shares.
 	 *
+	 * @param mixed $actionType
+	 * @param mixed $actionData
+	 *
 	 * @return bool
 	 */
 	private function deleteExistingShare($actionType, $actionData) {
