@@ -357,6 +357,7 @@ Zarafa.plugins.mdm.data.MDMDeviceRecordFields = [
 	{name: 'firstsynctime', type: 'date', dateFormat: 'timestamp'},
 	{name: 'lastsynctime', type: 'date', dateFormat: 'timestamp'},
 	{name: 'lastupdatetime', type: 'date', dateFormat: 'timestamp'},
+	{name: 'lastconnecttime', type: 'date', dateFormat: 'timestamp'},
 	{name: 'wipestatus', type: 'string'},
 	{name: 'policyname', type: 'string'},
 	{name: 'sharedfolders', type: 'string'},
@@ -816,8 +817,8 @@ Zarafa.plugins.mdm.settings.MDMSettingsWidget = Ext.extend(Zarafa.settings.ui.Se
 						header : _('Provisioning Status'),
 						renderer : Zarafa.plugins.mdm.ui.Renderers.provisioningStatus
 					},{
-						dataIndex : 'lastupdatetime',
-						header : _('Last Update'),
+						dataIndex : 'lastconnecttime',
+						header : _('Last Connect'),
 						renderer : Ext.util.Format.htmlEncode
 					},{
 						dataIndex : 'entryid',
@@ -1400,6 +1401,10 @@ Zarafa.plugins.mdm.dialogs.MDMDeviceGeneralTab = Ext.extend(Ext.form.FormPanel,
 			}, {
 				fieldLabel: _('Last updated'),
 				value: String.format(_('{0}'), new Date(config.record.get('lastupdatetime')).format(_('d F Y, H:i')))
+			}, {
+				fieldLabel: _('Last connect'),
+				value: String.format('{0}', new Date(config.record.get('lastconnecttime')).format(_('d F Y, H:i')))
+
 			}, {
 				fieldLabel: _('Status'),
 				listeners: {
@@ -1470,9 +1475,9 @@ Zarafa.plugins.mdm.dialogs.MDMDeviceGeneralTab = Ext.extend(Ext.form.FormPanel,
 		return {
 			xtype: 'panel',
 			border: false,
-            cls: 'mdm-synchronize-shared-panel',
+			cls: 'mdm-synchronize-shared-panel',
 			height: 50,
-            disabled: false,
+			disabled: false,
 			layout: {
 				type: 'hbox',
 				align: 'stretch',
@@ -2039,6 +2044,12 @@ Zarafa.plugins.mdm.ui.MDMFolderNodeUI = Ext.extend(Zarafa.hierarchy.ui.FolderNod
 			}
 		}
 
+		var checkboxMarkup = '';
+		if (cb) {
+			var checkboxId = Ext.id(null, 'zarafa-mdm-node-cb-');
+			checkboxMarkup = '<input class="x-tree-node-cb zarafa-hierarchy-node-cb" type="checkbox" id="' + checkboxId + '" name="' + checkboxId + '"' + (config.checked ? ' checked="checked"' : '') + ' />';
+		}
+
 		var icon = '<img src="' + (config.icon || this.emptyIcon) + '" class="x-tree-node-icon" unselectable="on" />',
 		nel,
 		href = config.href ? config.href : Ext.isGecko ? "" : "#",
@@ -2049,7 +2060,7 @@ Zarafa.plugins.mdm.ui.MDMFolderNodeUI = Ext.extend(Zarafa.hierarchy.ui.FolderNod
 					// expand icon
 					'<img src="' + this.emptyIcon + '" class="x-tree-ec-icon x-tree-elbow" />' +
 					// checkbox
-					(cb ? '<input class="x-tree-node-cb zarafa-hierarchy-node-cb" type="checkbox" ' + (config.checked ? 'checked="checked" />' : '/>') : '') +
+					checkboxMarkup +
 					// node icon
 					(isCalenderNode ? calendarSVGIcon : icon) +
 					// node element (this.elNode)
