@@ -750,18 +750,11 @@ class MAPISession {
 			$this->stores[$entryid] = $store;
 			$this->userstores[$name] = $entryid;
 		}
-		catch (MAPIException $e) {
-			error_log('Failed to open store. ' . $this->session_info["username"] .
-					  ' requested ' . bin2hex($entryid) . ($name ? " ({$name})" : ''));
-
-			return $e->getCode();
-		}
 		catch (Exception $e) {
-			// mapi_openmsgstore seems to throw another exception than MAPIException
-			// sometimes, so we add a safety net.
-			error_log('Failed to open store. ' . $this->session_info["username"] .
-					  ' requested ' . bin2hex($entryid) . ($name ? " ({$name})" : ''));
-
+			// mapi_openmsgstore seems to not only throw MAPIException
+			error_log(sprintf("openmsgstore %s failed (actor:%s, name:%s): %s",
+				bin2hex($entryid), $this->session_info["username"], $name,
+				$e->getDisplayMessage()));
 			return $e->getCode();
 		}
 
