@@ -4,5 +4,4 @@
  * Defines a base exception class for custom zarafa generated exceptions, these exceptions
  * are generated and handled by our application only.
  */
-class ZarafaException extends BaseException {
-}
+class ZarafaException extends BaseException {}
