@@ -17,7 +17,7 @@ class ContactItemModule extends ItemModule {
 
 		parent::__construct($id, $data);
 
-		$this->plaintext = true;
+		$this->plaintext = false;
 	}
 
 	/**
@@ -78,10 +78,9 @@ class ContactItemModule extends ItemModule {
 			// Check if message is distlist then we need to use different set of properties
 			$props = mapi_getprops($message, [PR_MESSAGE_CLASS]);
 
-			if (stripos((string) $props[PR_MESSAGE_CLASS], 'IPM.Distlist') !== false) {
+			if (class_match_prefix($props[PR_MESSAGE_CLASS], "IPM.Distlist"))
 				// for distlist we need to use different set of properties
 				$this->properties = $GLOBALS['properties']->getDistListProperties();
-			}
 
 			$data['item'] = $GLOBALS['operations']->getEmbeddedMessageProps($store, $message, $this->properties, $parentMessage, $attachNum);
 		}
@@ -89,13 +88,12 @@ class ContactItemModule extends ItemModule {
 			// Check if message is distlist then we need to use different set of properties
 			$props = mapi_getprops($message, [PR_MESSAGE_CLASS]);
 
-			if (stripos((string) $props[PR_MESSAGE_CLASS], 'IPM.Distlist') !== false) {
+			if (class_match_prefix($props[PR_MESSAGE_CLASS], "IPM.Distlist"))
 				// for distlist we need to use different set of properties
 				$this->properties = $GLOBALS['properties']->getDistListProperties();
-			}
 
 			// get message props of the message
-			$data['item'] = $GLOBALS['operations']->getMessageProps($store, $message, $this->properties, $this->plaintext);
+			$data['item'] = $GLOBALS['operations']->getMessageProps($store, $message, $this->properties, $this->plaintext, true);
 		}
 
 		// By openentry from address book, the entryid will differ, make it same as the origin
@@ -125,7 +123,7 @@ class ContactItemModule extends ItemModule {
 	 * @param array  $action        the action data, sent by the client
 	 */
 	#[Override]
-	public function save($store, $parententryid, $entryid, $action) {
+	public function save($store, $parententryid, $entryid, $action, $actionType = 'save') {
 		$properiesToDelete = []; // create an array of properties which should be deleted
 		// this array is passed to $GLOBALS['operations']->saveMessage() function
 
