@@ -106,7 +106,8 @@ class ItemModule extends Module {
 
 								// Update extra body information
 								if (isset($action["message_action"]['meetingTimeInfo']) && !empty($action["message_action"]['meetingTimeInfo'])) {
-									$req->setMeetingTimeInfo($action["message_action"]['meetingTimeInfo']);
+									$req->setMeetingTimeInfo($action["message_action"]['meetingTimeInfo'],
+										$action["message_action"]['mti_html'] ?? false);
 									unset($action["message_action"]['meetingTimeInfo']);
 								}
 
@@ -459,11 +460,20 @@ class ItemModule extends Module {
 			return;
 		}
 
-		// Decode smime signed messages on this message
-		parse_smime($store, $message);
+		// Detect whether S/MIME decoding or meeting request processing is required
+		$props = mapi_getprops($message, [PR_MESSAGE_CLASS]);
+		$messageClass = $props[PR_MESSAGE_CLASS] ?? '';
+		$requiresSmime = stripos((string) $messageClass, 'SMIME') !== false; /* infix match(!), cannot use class_match_prefix */
+		$requiresMeeting = class_match_prefix($messageClass, "IPM.Schedule.Meeting");
+
+		// Decode S/MIME signed messages only when needed
+		if ($requiresSmime) {
+			parse_smime($store, $message);
+		}
 
 		// Open embedded message if requested
 		$attachNum = !empty($action['attach_num']) ? $action['attach_num'] : false;
+
 		if ($attachNum) {
 			// get message props of sub message
 			$parentMessage = $message;
@@ -477,11 +487,16 @@ class ItemModule extends Module {
 		}
 		else {
 			// get message props of the message
-			$data['item'] = $GLOBALS['operations']->getMessageProps($store, $message, $this->properties, $this->plaintext);
-			$messageClass = $data['item']['props']['message_class'] ?? '';
+			$data['item'] = $GLOBALS['operations']->getMessageProps($store, $message, $this->properties, $this->plaintext, true);
+			$messageClass = $data['item']['props']['message_class'] ?? $messageClass;
+
+			// Determine again if meeting processing is required after parsing
+			if (!$requiresMeeting) {
+				$requiresMeeting = class_match_prefix($messageClass, "IPM.Schedule.Meeting");
+			}
 
 			// Check for meeting request, do processing if necessary
-			if (stripos($messageClass, 'IPM.Schedule.Meeting') !== false) {
+			if ($requiresMeeting) {
 				$req = new Meetingrequest($store, $message, $GLOBALS['mapisession']->getSession(), $this->directBookingMeetingRequest);
 
 				try {
@@ -586,7 +601,7 @@ class ItemModule extends Module {
 					$data['item']['props']['appointment_recurring_pattern'] = $recurr->saveRecurrencePattern();
 				}
 			}
-			elseif (stripos($messageClass, 'REPORT.IPM.NOTE.NDR') !== false) {
+			elseif (class_match_prefix($messageClass, "REPORT.IPM.NOTE.NDR")) {
 				// check if this message is a NDR (mail)message, if so, generate a new body message
 				$data['item']['props']['isHTML'] = false;
 				$data['item']['props']['body'] = $this->getNDRbody($message);
@@ -631,10 +646,11 @@ class ItemModule extends Module {
 	 *
 	 * @param object $store         MAPI Message Store Object
 	 * @param string $parententryid parent entryid of the message
+	 * @param mixed  $entryid       entryid of the message
 	 * @param array  $action        the action data, sent by the client
-	 * @param mixed  $entryid
+	 * @param string $actionType    The action type which triggered this action
 	 */
-	public function save($store, $parententryid, $entryid, $action) {
+	public function save($store, $parententryid, $entryid, $action, $actionType = 'save') {
 		$result = false;
 
 		if (isset($action["props"])) {
@@ -932,7 +948,8 @@ class ItemModule extends Module {
 
 		// Update extra body information
 		if (isset($action['message_action']['meetingTimeInfo']) && !empty($action['message_action']['meetingTimeInfo'])) {
-			$req->setMeetingTimeInfo($action["message_action"]['meetingTimeInfo']);
+			$req->setMeetingTimeInfo($action["message_action"]['meetingTimeInfo'],
+				$action["message_action"]['mti_html'] ?? false);
 			unset($action["message_action"]['meetingTimeInfo']);
 		}
 
