@@ -102,6 +102,15 @@ class ResolveNamesModule extends Module {
 		try {
 			// First, try an addressbook lookup
 			$rows = mapi_ab_resolvename($ab, [[PR_DISPLAY_NAME => $searchstr]], $flags);
+
+			// If the lookup succeeded but we should also check for exact hidden matches
+			if (defined('ENABLE_RESOLVE_HIDDEN_USERS') && ENABLE_RESOLVE_HIDDEN_USERS && !($flags & EMS_AB_ADDRESS_LOOKUP)) {
+				$hiddenRows = $this->resolveHiddenExactMatches($ab, $query);
+				if (!empty($hiddenRows)) {
+					$rows = $this->mergeAndDeduplicateRows($rows, $hiddenRows);
+				}
+			}
+
 			$this->searchContactsFolders($ab, $ab_dir, $searchstr, $rows);
 		}
 		catch (MAPIException $e) {
@@ -118,10 +127,23 @@ class ResolveNamesModule extends Module {
 				$rows = mapi_table_queryallrows($table, [PR_ACCOUNT, PR_ADDRTYPE, PR_DISPLAY_NAME, PR_ENTRYID, PR_SEARCH_KEY, PR_OBJECT_TYPE, PR_SMTP_ADDRESS, PR_DISPLAY_TYPE_EX, PR_EMAIL_ADDRESS, PR_OBJECT_TYPE, PR_DISPLAY_TYPE]);
 
 				$rows = array_merge($rows, $this->getAmbigiousContactResolveResults($ab, $searchstr, $excludeGABGroups));
+
+				// Also check for hidden users if enabled and this is an exact match
+				if (defined('ENABLE_RESOLVE_HIDDEN_USERS') && ENABLE_RESOLVE_HIDDEN_USERS) {
+					$hiddenRows = $this->resolveHiddenExactMatches($ab, $query);
+					if (!empty($hiddenRows)) {
+						$rows = $this->mergeAndDeduplicateRows($rows, $hiddenRows);
+					}
+				}
 			}
 			elseif ($e->getCode() == MAPI_E_NOT_FOUND) {
 				$rows = [];
-				if ($query['address_type'] === 'SMTP') {
+
+				if (defined('ENABLE_RESOLVE_HIDDEN_USERS') && ENABLE_RESOLVE_HIDDEN_USERS) {
+					$rows = $this->resolveHiddenExactMatches($ab, $query);
+				}
+
+				if (empty($rows) && (($query['address_type'] ?? '') === 'SMTP')) {
 					// If we still can't find anything, and we were searching for a SMTP user
 					// we can generate a oneoff entry which contains the information of the user.
 					if (!empty($query['email_address'])) {
@@ -137,6 +159,9 @@ class ResolveNamesModule extends Module {
 						$this->searchContactsFolders($ab, $ab_dir, $searchstr, $rows);
 					}
 				}
+				elseif (empty($rows)) {
+					$this->searchContactsFolders($ab, $ab_dir, $searchstr, $rows);
+				}
 			}
 			else {
 				// all other errors should be propagated to higher level exception handlers
@@ -211,6 +236,121 @@ class ResolveNamesModule extends Module {
 		return $items;
 	}
 
+	/**
+	 * Try to resolve a hidden user by matching the provided query exactly against
+	 * common address book properties. Hidden entries are not returned in regular
+	 * searches, but the EMS_AB_ADDRESS_LOOKUP flag allows us to perform an exact
+	 * lookup that also returns hidden entries.
+	 *
+	 * @param resource $ab    The addressbook
+	 * @param array    $query Resolve query sent by the client
+	 *
+	 * @return array
+	 */
+	protected function resolveHiddenExactMatches($ab, $query) {
+		if (!defined('ENABLE_RESOLVE_HIDDEN_USERS') || !ENABLE_RESOLVE_HIDDEN_USERS) {
+			return [];
+		}
+
+		$candidates = [];
+
+		if (!empty($query['display_name'])) {
+			$candidates[] = trim((string) $query['display_name']);
+		}
+
+		if (!empty($query['email_address'])) {
+			$candidates[] = trim((string) $query['email_address']);
+		}
+
+		$candidates = array_values(array_unique(array_filter($candidates, 'strlen')));
+		$addressType = strtoupper((string) ($query['address_type'] ?? ''));
+
+		foreach ($candidates as $candidate) {
+			$lookups = [PR_DISPLAY_NAME];
+
+			if ($addressType === 'EX') {
+				$lookups[] = PR_ACCOUNT;
+			}
+
+			if (str_contains($candidate, '@')) {
+				$lookups[] = PR_EMAIL_ADDRESS;
+				$lookups[] = PR_SMTP_ADDRESS;
+
+				if ($addressType !== 'EX') {
+					$lookups[] = PR_ACCOUNT;
+				}
+			}
+
+			foreach (array_unique($lookups) as $property) {
+				$rows = $this->resolveNameByProperty($ab, $property, $candidate);
+				if (!empty($rows)) {
+					return $rows;
+				}
+			}
+		}
+
+		return [];
+	}
+
+	/**
+	 * Execute an exact resolve against the GAB for the provided property.
+	 *
+	 * @param resource $ab       The addressbook
+	 * @param int      $property Property tag used for the lookup
+	 * @param string   $value    Search value
+	 *
+	 * @return array
+	 */
+	protected function resolveNameByProperty($ab, $property, $value) {
+		if ($value === '') {
+			return [];
+		}
+
+		try {
+			return mapi_ab_resolvename($ab, [[$property => $value]], EMS_AB_ADDRESS_LOOKUP);
+		}
+		catch (MAPIException $e) {
+			if ($e->getCode() == MAPI_E_NOT_FOUND || $e->getCode() == MAPI_E_AMBIGUOUS_RECIP) {
+				return [];
+			}
+
+			throw $e;
+		}
+	}
+
+	/**
+	 * Merge two arrays of rows and remove duplicates based on entryid.
+	 * This prevents the same user from appearing multiple times when they're
+	 * found through both normal and hidden user resolution.
+	 *
+	 * @param array $existingRows Existing rows from table/resolve queries
+	 * @param array $newRows      New rows from hidden user resolution
+	 *
+	 * @return array Merged array with duplicates removed
+	 */
+	protected function mergeAndDeduplicateRows($existingRows, $newRows) {
+		// Build a map of existing entryids
+		$entryidMap = [];
+		foreach ($existingRows as $row) {
+			if (isset($row[PR_ENTRYID])) {
+				$entryidMap[bin2hex($row[PR_ENTRYID])] = true;
+			}
+		}
+
+		// Add new rows only if they don't already exist
+		foreach ($newRows as $row) {
+			if (isset($row[PR_ENTRYID])) {
+				$entryidHex = bin2hex($row[PR_ENTRYID]);
+				if (!isset($entryidMap[$entryidHex])) {
+					$existingRows[] = $row;
+					$entryidMap[$entryidHex] = true;
+				}
+			}
+		}
+
+		return $existingRows;
+	}
+
 	/**
 	 * Used to find multiple entries from the contact folders in the Addressbook when resolving
 	 * returned an ambiguous result. It will find the Contact folders in the Addressbook and
