@@ -17,6 +17,7 @@ class SettingsModule extends Module {
 	/**
 	 * Executes all the actions in the $data variable.
 	 */
+	#[Override]
 	public function execute() {
 		foreach ($this->data as $actionType => $action) {
 			if (isset($actionType)) {
@@ -47,10 +48,7 @@ class SettingsModule extends Module {
 							$this->handleUnknownActionType($actionType);
 					}
 				}
-				catch (SettingsException $e) {
-					$this->processException($e, $actionType);
-				}
-				catch (MAPIException $e) {
+				catch (MAPIException|SettingsException $e) {
 					$this->processException($e, $actionType);
 				}
 			}
