@@ -15,6 +15,7 @@ class AppointmentListNotifier extends ListNotifier {
 	 *
 	 * @return array The properties mapping
 	 */
+	#[Override]
 	protected function getPropertiesList() {
 		return $GLOBALS["properties"]->getAppointmentListProperties();
 	}
@@ -27,6 +28,7 @@ class AppointmentListNotifier extends ListNotifier {
 	 * @param string $entryid entryid
 	 * @param mixed  $props
 	 */
+	#[Override]
 	public function update($event, $entryid, $props) {
 		switch ($event) {
 			case TABLE_SAVE:
@@ -61,9 +63,9 @@ class AppointmentListNotifier extends ListNotifier {
 									"content_unread" => $folderProps[PR_CONTENT_UNREAD],
 									// Add store_entryid,entryid of folder and display_name of folder
 									// to JSON data in order to refresh the list.
-									"store_entryid" => bin2hex($folderProps[PR_STORE_ENTRYID]),
-									"parent_entryid" => bin2hex($folderProps[PR_PARENT_ENTRYID]),
-									"entryid" => bin2hex($folderProps[PR_ENTRYID]),
+									"store_entryid" => bin2hex((string) $folderProps[PR_STORE_ENTRYID]),
+									"parent_entryid" => bin2hex((string) $folderProps[PR_PARENT_ENTRYID]),
+									"entryid" => bin2hex((string) $folderProps[PR_ENTRYID]),
 									"display_name" => $folderProps[PR_DISPLAY_NAME],
 								],
 							],
