@@ -12,6 +12,7 @@ class ListNotifier extends Notifier {
 	 *                by this notifier. The bitmask can consist of the
 	 *                OBJECT_SAVE, OBJECT_DELETE, TABLE_SAVE, TABLE_DELETE, REQUEST_START and REQUEST_END flags
 	 */
+	#[Override]
 	public function getEvents() {
 		return OBJECT_SAVE | TABLE_SAVE | TABLE_DELETE;
 	}
@@ -34,6 +35,7 @@ class ListNotifier extends Notifier {
 	 * @param string $entryid entryid
 	 * @param mixed  $props
 	 */
+	#[Override]
 	public function update($event, $entryid, $props) {
 		switch ($event) {
 			case TABLE_SAVE:
@@ -61,9 +63,9 @@ class ListNotifier extends Notifier {
 									"content_unread" => $folderProps[PR_CONTENT_UNREAD],
 									// Add store_entryid,entryid of folder and display_name of folder
 									// to JSON data in order to refresh the list.
-									"store_entryid" => bin2hex($folderProps[PR_STORE_ENTRYID]),
-									"parent_entryid" => bin2hex($folderProps[PR_PARENT_ENTRYID]),
-									"entryid" => bin2hex($folderProps[PR_ENTRYID]),
+									"store_entryid" => bin2hex((string) $folderProps[PR_STORE_ENTRYID]),
+									"parent_entryid" => bin2hex((string) $folderProps[PR_PARENT_ENTRYID]),
+									"entryid" => bin2hex((string) $folderProps[PR_ENTRYID]),
 									"display_name" => $folderProps[PR_DISPLAY_NAME],
 								],
 							],
@@ -75,21 +77,21 @@ class ListNotifier extends Notifier {
 				break;
 
 			case TABLE_DELETE:
-				$folderEntryID = isset($props[PR_PARENT_ENTRYID]) ? $props[PR_PARENT_ENTRYID] : false;
+				$folderEntryID = $props[PR_PARENT_ENTRYID] ?? false;
 
 				if (isset($props[PR_ENTRYID]) && $folderEntryID) {
 					$data = [];
-					$data["parent_entryid"] = bin2hex($folderEntryID);
+					$data["parent_entryid"] = bin2hex((string) $folderEntryID);
 
 					if (is_array($props[PR_ENTRYID])) {
 						$data["entryid"] = [];
 
 						foreach ($props[PR_ENTRYID] as $entryid) {
-							array_push($data["entryid"], bin2hex($entryid));
+							array_push($data["entryid"], bin2hex((string) $entryid));
 						}
 					}
 					else {
-						$data["entryid"] = bin2hex($props[PR_ENTRYID]);
+						$data["entryid"] = bin2hex((string) $props[PR_ENTRYID]);
 					}
 
 					$this->addNotificationActionData("delete", ["item" => [$data]]);
