@@ -1,24 +1,24 @@
 <?php
-	header("Content-Type: text/javascript; charset=utf-8");
+header("Content-Type: text/javascript; charset=utf-8");
 
-	header('Expires: ' . gmdate('D, d M Y H:i:s', time() + EXPIRES_TIME) . ' GMT');
-	header('Cache-Control: max-age=' . EXPIRES_TIME . ',must-revalidate');
+header('Expires: ' . gmdate('D, d M Y H:i:s', time() + EXPIRES_TIME) . ' GMT');
+header('Cache-Control: max-age=' . EXPIRES_TIME . ',must-revalidate');
 
-	// Pragma: cache doesn't really exist. But since session_start() automatically
-	// outputs a Pragma: no-cache, the only way to override that is to output something else
-	// in that header. So that's what we do here. It might as well have read 'Pragma: foo'.
-	header('Pragma: cache');
+// Pragma: cache doesn't really exist. But since session_start() automatically
+// outputs a Pragma: no-cache, the only way to override that is to output something else
+// in that header. So that's what we do here. It might as well have read 'Pragma: foo'.
+header('Pragma: cache');
 
-	// compress output
-	ob_start("ob_gzhandler");
+// compress output
+ob_start("ob_gzhandler");
 
-	$translations = $Language->getTranslations();
+$translations = $Language->getTranslations();
 
 /**
  * Convert the charset to UTF-8. If it is an array it will loop through all it's
  * items and encodes each item.
  *
- * @param $source String|Array Input string or array with strings
+ * @param $source  String|Array Input string or array with strings
  * @param $charset String Original charset of the source string(s)
  *
  * @return string Source string encoded with the new charset
@@ -27,11 +27,11 @@ function changeTranslationCharsetToUTF8($source, $charset) {
 	if (is_array($source)) {
 		$sourceCount = count($source);
 		for ($i = 0; $i < $sourceCount; ++$i) {
-			$source[$i] = iconv($charset, 'UTF-8//TRANSLIT', $source[$i]);
+			$source[$i] = iconv((string) $charset, 'UTF-8//TRANSLIT', (string) $source[$i]);
 		}
 	}
 	elseif (is_string($source)) {
-		$source = iconv($charset, 'UTF-8//TRANSLIT', $source);
+		$source = iconv((string) $charset, 'UTF-8//TRANSLIT', $source);
 	}
 
 	return $source;
@@ -61,11 +61,11 @@ foreach ($translations as $domain => $translation_list) {
 	foreach ($translations[$domain] as $key => $translationdomain) {
 		$charset = 'UTF-8';
 		if ($translationdomain['msgid'] == '') {
-			preg_match('/charset=([a-zA-Z0-9_-]+)/', $translationdomain['msgstr'], $matches);
+			preg_match('/charset=([a-zA-Z0-9_-]+)/', (string) $translationdomain['msgstr'], $matches);
 			if (count($matches) > 0 && isset($matches[1])) {
 				$charset = strtoupper($matches[1]);
 			}
-			preg_match('/Plural-Forms: ([^\n]+)/', $translationdomain['msgstr'], $matches);
+			preg_match('/Plural-Forms: ([^\n]+)/', (string) $translationdomain['msgstr'], $matches);
 			if (count($matches) > 0 && isset($matches[1])) {
 				$pluralForms = $matches[1];
 			}
@@ -98,11 +98,11 @@ foreach ($translations as $domain => $translation_list) {
 		}
 
 		// Escape the \n slash to prevent the translation file out breaking.
-		$msgid = str_replace("\n", "\\n", addslashes($translation['msgid']));
+		$msgid = str_replace("\n", "\\n", addslashes((string) $translation['msgid']));
 		// Prepare the $context to be glued together with the msgid together in JS
 		if ($translation['msgctxt'] !== false) {
 			// Escape the \n slash to prevent the translation file out breaking.
-			$context = str_replace("\n", "\\n", addslashes($translation['msgctxt']));
+			$context = str_replace("\n", "\\n", addslashes((string) $translation['msgctxt']));
 			// We cannot do it in PHP as this will cause an issue with the backslash
 			$context = '"' . $context . '\004"+';
 		}
@@ -113,7 +113,7 @@ foreach ($translations as $domain => $translation_list) {
 		// If the translation is in plural form we have to set it as an array
 		if ($translation['msgid_plural'] === false) {
 			// Escape the \n slash to prevent the translation file out breaking.
-			$msgstr = str_replace("\n", "\\n", addslashes($translation['msgstr'])); ?>
+			$msgstr = str_replace("\n", "\\n", addslashes((string) $translation['msgstr'])); ?>
 	this.translations["<?php echo $domain; ?>"][<?php echo $context; ?>"<?php echo $msgid; ?>"] = "<?php echo $msgstr; ?>";
 <?php
 		}
@@ -123,7 +123,7 @@ foreach ($translations as $domain => $translation_list) {
 <?php
 			for ($j = 0; $j < count($translation['msgstr']); ++$j) {
 				// Escape the \n slash to prevent the translation file out breaking.
-				$msgstr = str_replace("\n", "\\n", addslashes($translation['msgstr'][$j])); ?>
+				$msgstr = str_replace("\n", "\\n", addslashes((string) $translation['msgstr'][$j])); ?>
 	this.translations["<?php echo $domain; ?>"][<?php echo $context; ?>"<?php echo $msgid; ?>"][<?php echo $j; ?>] = "<?php echo $msgstr; ?>";
 <?php
 			}
