@@ -493,10 +493,10 @@ function parse_smime($store, $message) {
 	$props = mapi_getprops($message, [PR_MESSAGE_CLASS, PR_MESSAGE_FLAGS,
 		PR_SENT_REPRESENTING_NAME, PR_SENT_REPRESENTING_ENTRYID, PR_SENT_REPRESENTING_SEARCH_KEY,
 		PR_SENT_REPRESENTING_EMAIL_ADDRESS, PR_SENT_REPRESENTING_SMTP_ADDRESS,
-		PR_SENT_REPRESENTING_ADDRTYPE, PR_CLIENT_SUBMIT_TIME, PR_TRANSPORT_MESSAGE_HEADERS]);
+		PR_SENT_REPRESENTING_ADDRTYPE, PR_CLIENT_SUBMIT_TIME, PR_TRANSPORT_MESSAGE_HEADERS, PR_REPLY_RECIPIENT_ENTRIES]);
 	$read = $props[PR_MESSAGE_FLAGS] & MSGFLAG_READ;
 
-	if (isset($props[PR_MESSAGE_CLASS]) && stripos((string) $props[PR_MESSAGE_CLASS], 'IPM.Note.SMIME.MultipartSigned') !== false) {
+	if (class_match_prefix($props[PR_MESSAGE_CLASS], "IPM.Note.SMIME.MultipartSigned")) {
 		// this is a signed message. decode it.
 		$atable = mapi_message_getattachmenttable($message);
 
@@ -536,7 +536,7 @@ function parse_smime($store, $message) {
 				mapi_message_modifyrecipients($message, MODRECIP_ADD, $origRecipients);
 			}
 
-			mapi_setprops($message, [
+			$tmpprops = [
 				PR_MESSAGE_CLASS => $props[PR_MESSAGE_CLASS],
 				PR_SENT_REPRESENTING_NAME => $props[PR_SENT_REPRESENTING_NAME],
 				PR_SENT_REPRESENTING_ENTRYID => $props[PR_SENT_REPRESENTING_ENTRYID],
@@ -545,11 +545,15 @@ function parse_smime($store, $message) {
 				PR_SENT_REPRESENTING_SMTP_ADDRESS => $props[PR_SENT_REPRESENTING_SMTP_ADDRESS] ?? '',
 				PR_SENT_REPRESENTING_ADDRTYPE => $props[PR_SENT_REPRESENTING_ADDRTYPE] ?? 'SMTP',
 				PR_CLIENT_SUBMIT_TIME => $props[PR_CLIENT_SUBMIT_TIME] ?? time(),
-				PR_TRANSPORT_MESSAGE_HEADERS => ($props[PR_TRANSPORT_MESSAGE_HEADERS] ?? "") . $inner_headers,
-			]);
+				PR_TRANSPORT_MESSAGE_HEADERS => ($props[PR_TRANSPORT_MESSAGE_HEADERS] ?? ""),
+			];
+			if (isset($props[PR_REPLY_RECIPIENT_ENTRIES])) {
+				$tmpprops[PR_REPLY_RECIPIENT_ENTRIES] = $props[PR_REPLY_RECIPIENT_ENTRIES];
+			}
+			mapi_setprops($message, $tmpprops);
 		}
 	}
-	elseif (isset($props[PR_MESSAGE_CLASS]) && stripos((string) $props[PR_MESSAGE_CLASS], 'IPM.Note.SMIME') !== false) {
+	elseif (class_match_prefix($props[PR_MESSAGE_CLASS], "IPM.Note.SMIME")) {
 		// this is a encrypted message. decode it.
 		$attachTable = mapi_message_getattachmenttable($message);
 
@@ -583,10 +587,9 @@ function parse_smime($store, $message) {
 			// after decrypting $message is a IPM.Note message,
 			// deleting an attachment removes an actual attachment of the message
 			$mprops = mapi_getprops($message, [PR_MESSAGE_CLASS]);
-			if (isSmimePluginEnabled() && isset($mprops[PR_MESSAGE_CLASS]) &&
-				stripos((string) $mprops[PR_MESSAGE_CLASS], 'IPM.Note.SMIME') !== false) {
+			if (isSmimePluginEnabled() &&
+			    class_match_prefix($mprops[PR_MESSAGE_CLASS], "IPM.Note.SMIME"))
 				mapi_message_deleteattach($message, $attnum);
-			}
 
 			$decapRcptTable = mapi_message_getrecipienttable($message);
 			$decapRecipients = mapi_table_queryallrows($decapRcptTable, $GLOBALS["properties"]->getRecipientProperties());
@@ -1009,3 +1012,18 @@ function getLocalStart($ts, $tz) {
 
 	return $ts;
 }
+
+/**
+ * @h:	PR_MESSAGE_CLASS value
+ * @n:	prefix to test for
+ */
+function class_match_prefix($h, $n)
+{
+	if (!isset($h))
+		return false;
+	$z = strlen($n);
+	$r = strncasecmp($h, $n, $z);
+	if ($r != 0)
+		return false;
+	return strlen($h) == $z || $h[$z] == '.' ? true : false;
+}
